# PlantsAI

[![Python package](https://github.com/PlantsAI/plantsai/actions/workflows/python-package.yml/badge.svg)](https://github.com/PlantsAI/plantsai/actions/workflows/python-package.yml)
[![Upload Python Package](https://github.com/PlantsAI/plantsai/actions/workflows/python-publish.yml/badge.svg)](https://github.com/PlantsAI/plantsai/actions/workflows/python-publish.yml)

A powerful plant identifier to identify flowers, leaves, trees, and more in seconds! 🌱

## Installation

```bash
pip install plantsai
```

## Usage

### CLI

PlantsAI may be used directly in the Command Line Interface (CLI):

```bash
plantsai
```

### Python

PlantsAI may also be used directly in a Python environment as a library:

```python
import plantsai
```
